summaryrefslogtreecommitdiffstats
path: root/include
diff options
context:
space:
mode:
authorRyan Bloom <rbb@apache.org>2000-09-19 22:56:09 +0200
committerRyan Bloom <rbb@apache.org>2000-09-19 22:56:09 +0200
commit96c98ff58b01a8adb368cf916f6676e938e6ab42 (patch)
treea9d30d6edc65438fc4b2331dc42947ab1ca44508 /include
parentChange the registered filter name to XLATEOUT (from XLATE). (diff)
downloadapache2-96c98ff58b01a8adb368cf916f6676e938e6ab42.tar.xz
apache2-96c98ff58b01a8adb368cf916f6676e938e6ab42.zip
tart getting things setup for input filtering. All this basically does
is add part of the infrastructure. Namely: 1) filter list in the conn_rec, which is where the input filter list must live 2) Split the register_filter into multiple functions, one to register input filters the other to register output filters. 3) Modify existing modules so they still work. git-svn-id: https://svn.apache.org/repos/asf/httpd/httpd/trunk@86251 13f79535-47bb-0310-9956-ffa450edef68
Diffstat (limited to 'include')
-rw-r--r--include/httpd.h6
-rw-r--r--include/util_filter.h23
2 files changed, 20 insertions, 9 deletions
diff --git a/include/httpd.h b/include/httpd.h
index 73eb089e6a..c422b01da6 100644
--- a/include/httpd.h
+++ b/include/httpd.h
@@ -814,9 +814,6 @@ struct request_rec {
/** A flag to determine if the eos bucket has been sent yet
* @defvar int eos_sent */
int eos_sent;
- /** A list of output filters to be used for this request
- * @defvar ap_filter_t *filters */
- struct ap_filter_t *input_filters;
/* Things placed at the end of the record to avoid breaking binary
* compatibility. It would be nice to remember to reorder the entire
@@ -881,6 +878,9 @@ struct conn_rec {
/** send note from one module to another, must remain valid for all
* requests on this conn */
apr_table_t *notes;
+ /** A list of input filters to be used for this request
+ * @defvar ap_filter_t *filters */
+ struct ap_filter_t *input_filters;
};
/* Per-vhost config... */
diff --git a/include/util_filter.h b/include/util_filter.h
index 0f73772f0f..03ca49cf94 100644
--- a/include/util_filter.h
+++ b/include/util_filter.h
@@ -250,16 +250,27 @@ API_EXPORT(apr_status_t) ap_pass_brigade(ap_filter_t *filter, ap_bucket_brigade
* The filter's callback and type should be passed.
*/
/**
* Register a filter for later use. This allows modules to name their filter
* functions for later addition to a specific request
* @param name The name to attach to the filter function
* @param filter_func The filter function to name
* @param The type of filter function, either AP_FTYPE_CONTENT or AP_FTYPE_CONNECTION
- * @deffunc void ap_register_filter(const char *name, ap_filter_func filter_func, ap_filter_type ftype)
+ * @deffunc void ap_register_input_filter(const char *name, ap_filter_func filter_func, ap_filter_type ftype)
*/
-API_EXPORT(void) ap_register_filter(const char *name,
- ap_filter_func filter_func,
- ap_filter_type ftype);
+API_EXPORT(void) ap_register_input_filter(const char *name,
+ ap_filter_func filter_func,
+ ap_filter_type ftype);
+/**
+ * Register an output filter for later use. This allows modules to name their
+ * filter functions for later addition to a specific request
+ * @param name The name to attach to the filter function
+ * @param filter_func The filter function to name
+ * @param The type of filter function, either AP_FTYPE_CONTENT or AP_FTYPE_CONNECTION
+ * @deffunc void ap_register_output_filter(const char *name, ap_filter_func filter_func, ap_filter_type ftype)
+ */
+API_EXPORT(void) ap_register_output_filter(const char *name,
+ ap_filter_func filter_func,
+ ap_filter_type ftype);
/*
* ap_add_filter():
@@ -250,16 +250,27 @@ API_EXPORT(apr_status_t) ap_pass_brigade(ap_filter_t *filter, ap_bucket_brigade
*/
/**
- * Register a filter for later use. This allows modules to name their filter
- * functions for later addition to a specific request
+ * Register an input filter for later use. This allows modules to name their
+ * filter functions for later addition to a specific request
* @param name The name to attach to the filter function
* @param filter_func The filter function to name